{
    "$graph": [
        {
            "label": "Merge rRNA Alignments",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "align_merge",
            "arguments": [
                "-filter",
                "align_length >= 60",
                "-ifmt",
                "seq-align-set",
                "-max-discontinuity",
                "20",
                "-collated",
                "-compart",
                "-fill-gaps",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#align_merge.cwl/alignments"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#align_merge.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#align_merge.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#align_merge.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "align.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#align_merge.cwl/output"
                }
            ],
            "id": "#align_merge.cwl",
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#align_merge.cwl/aligns"
                }
            ]
        },
        {
            "label": "Post-process CMsearch annotations",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "annot_merge",
            "arguments": [
                "-unique",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#annot_merge.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#annot_merge.cwl/input"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "annots.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#annot_merge.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#annot_merge.cwl/annots"
                }
            ],
            "id": "#annot_merge.cwl"
        },
        {
            "label": "BLAST against rRNA db, execution",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "blastn_wnode",
            "arguments": [
                "-evalue",
                "0.01",
                "-max_target_seqs",
                "250",
                "-soft_masking",
                "true",
                "-task",
                "blastn",
                "-word_size",
                "12",
                "-swap-rows",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#blastn_wnode.cwl/asn_cache"
                },
                {
                    "type": "Directory",
                    "id": "#blastn_wnode.cwl/blastdb_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#blastn_wnode.cwl/input_jobs"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#blastn_wnode.cwl/output_dir"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#blastn_wnode.cwl/outdir"
                }
            ],
            "id": "#blastn_wnode.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA), execution",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        }
                    ]
                },
                {
                    "class": "ResourceRequirement",
                    "ramMax": 3000
                }
            ],
            "baseCommand": "cmsearch_wnode",
            "arguments": [
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#cmsearch_wnode.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "int"
                    ],
                    "default": 0,
                    "inputBinding": {
                        "prefix": "-cmsearch-cpu"
                    },
                    "id": "#cmsearch_wnode.cwl/cmsearch_cpu"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "/panfs/pan1.be-md.ncbi.nlm.nih.gov/gpipe/bacterial_pipeline/system/third-party/bin",
                    "inputBinding": {
                        "prefix": "-cmsearch-path"
                    },
                    "id": "#cmsearch_wnode.cwl/cmsearch_path"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input-jobs"
                    },
                    "id": "#cmsearch_wnode.cwl/input_jobs"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-model-path"
                    },
                    "id": "#cmsearch_wnode.cwl/model_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "output",
                    "inputBinding": {
                        "prefix": "-O"
                    },
                    "id": "#cmsearch_wnode.cwl/output_dir"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-rfam-amendments"
                    },
                    "id": "#cmsearch_wnode.cwl/rfam_amendments"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-rfam-stockholm"
                    },
                    "id": "#cmsearch_wnode.cwl/rfam_stockholm"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-taxon-db"
                    },
                    "id": "#cmsearch_wnode.cwl/taxon_db"
                }
            ],
            "outputs": [
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.asn_cache.basename)"
                    },
                    "id": "#cmsearch_wnode.cwl/asncache"
                },
                {
                    "type": "Directory",
                    "outputBinding": {
                        "glob": "$(inputs.output_dir)"
                    },
                    "id": "#cmsearch_wnode.cwl/outdir"
                }
            ],
            "id": "#cmsearch_wnode.cwl"
        },
        {
            "label": "BLAST against rRNA db, gather",
            "class": "CommandLineTool",
            "baseCommand": "gpx_make_outputs",
            "arguments": [
                "-unzip",
                "*",
                "-num-partitions",
                "1"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_make_outputs.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "blast.#.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_make_outputs.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "blast.*.asn"
                    },
                    "id": "#gpx_make_outputs.cwl/blast_align"
                }
            ],
            "id": "#gpx_make_outputs.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA), gather",
            "class": "CommandLineTool",
            "baseCommand": "gpx_qdump",
            "arguments": [
                "-unzip",
                "*"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-input-path"
                    },
                    "id": "#gpx_qdump.cwl/input_path"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "cmsearch.asn",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qdump.cwl/output_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output_name)"
                    },
                    "id": "#gpx_qdump.cwl/annots"
                }
            ],
            "id": "#gpx_qdump.cwl"
        },
        {
            "label": "BLAST against rRNA db, scatter",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-affinity",
                "subject",
                "-max-batch-length",
                "50000",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "inputBinding": {
                        "prefix": "-db",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb"
                },
                {
                    "type": [
                        "null",
                        "Directory"
                    ],
                    "id": "#gpx_qsubmit_blastn.cwl/blastdb_dir"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_blastn.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_blastn.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA), scatter",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "gpx_qsubmit",
            "arguments": [
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/asn_cache"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "jobs.xml",
                    "inputBinding": {
                        "prefix": "-output"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/output"
                },
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-ids"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.output)"
                    },
                    "id": "#gpx_qsubmit_gcmsearch.cwl/jobs"
                }
            ],
            "id": "#gpx_qsubmit_gcmsearch.cwl"
        },
        {
            "label": "Generate rRNA Annotation",
            "class": "CommandLineTool",
            "requirements": [
                {
                    "class": "InitialWorkDirRequirement",
                    "listing": [
                        {
                            "entry": "$(inputs.asn_cache)",
                            "writable": false
                        },
                        {
                            "entry": "$(inputs.blastdb_dir)",
                            "writable": false
                        }
                    ]
                }
            ],
            "baseCommand": "ribosomal_align2annot",
            "arguments": [
                "-filter-accept",
                "pct_identity_gap >= 70",
                "-gap-tolerance",
                "1000",
                "-submission-mode-genbank",
                "-nogenbank"
            ],
            "inputs": [
                {
                    "type": "File",
                    "inputBinding": {
                        "prefix": "-input"
                    },
                    "id": "#ribosomal_align2annot.cwl/alignments"
                },
                {
                    "type": [
                        "null",
                        "string"
                    ],
                    "default": "annotations.asn",
                    "inputBinding": {
                        "prefix": "-o"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotation"
                },
                {
                    "type": "Directory",
                    "inputBinding": {
                        "prefix": "-asn-cache"
                    },
                    "id": "#ribosomal_align2annot.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-blastdb",
                        "valueFrom": "$(inputs.blastdb_dir.path)/$(inputs.blastdb)"
                    },
                    "id": "#ribosomal_align2annot.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#ribosomal_align2annot.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "inputBinding": {
                        "prefix": "-product-name"
                    },
                    "id": "#ribosomal_align2annot.cwl/product_name"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputBinding": {
                        "glob": "$(inputs.annotation)"
                    },
                    "id": "#ribosomal_align2annot.cwl/annotations"
                }
            ],
            "id": "#ribosomal_align2annot.cwl"
        },
        {
            "label": "Non-Coding Bacterial Genes",
            "class": "Workflow",
            "requirements": [
                {
                    "class": "SubworkflowFeatureRequirement"
                }
            ],
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#main/16s_blastdb_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/23s_blastdb_dir"
                },
                {
                    "type": "Directory",
                    "id": "#main/asn_cache"
                },
                {
                    "type": {
                        "type": "array",
                        "items": "boolean"
                    },
                    "id": "#main/go"
                },
                {
                    "type": "File",
                    "id": "#main/model_path"
                },
                {
                    "type": "File",
                    "id": "#main/rfam_amendments"
                },
                {
                    "type": "File",
                    "id": "#main/rfam_stockholm"
                },
                {
                    "type": "File",
                    "id": "#main/seqids"
                },
                {
                    "type": "File",
                    "id": "#main/taxon_db"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#main/bacterial_noncoding_16S/annotations",
                    "id": "#main/annotations_16s"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bacterial_noncoding_23S/annotations",
                    "id": "#main/annotations_23s"
                },
                {
                    "type": "File",
                    "outputSource": "#main/bacterial_noncoding_5S/annots",
                    "id": "#main/annotations_5s"
                }
            ],
            "steps": [
                {
                    "run": "#wf_blastn.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/bacterial_noncoding_16S/asn_cache"
                        },
                        {
                            "default": "blastdb",
                            "id": "#main/bacterial_noncoding_16S/blastdb"
                        },
                        {
                            "source": "#main/16s_blastdb_dir",
                            "id": "#main/bacterial_noncoding_16S/blastdb_dir"
                        },
                        {
                            "default": "annotations_16s.asn",
                            "id": "#main/bacterial_noncoding_16S/outname"
                        },
                        {
                            "default": "16S ribosomal RNA",
                            "id": "#main/bacterial_noncoding_16S/product_name"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/bacterial_noncoding_16S/seqids"
                        }
                    ],
                    "out": [
                        "#main/bacterial_noncoding_16S/annotations"
                    ],
                    "id": "#main/bacterial_noncoding_16S"
                },
                {
                    "run": "#wf_blastn.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/bacterial_noncoding_23S/asn_cache"
                        },
                        {
                            "default": "Ribosom23S",
                            "id": "#main/bacterial_noncoding_23S/blastdb"
                        },
                        {
                            "source": "#main/23s_blastdb_dir",
                            "id": "#main/bacterial_noncoding_23S/blastdb_dir"
                        },
                        {
                            "default": "annotations_23s.asn",
                            "id": "#main/bacterial_noncoding_23S/outname"
                        },
                        {
                            "default": "23S ribosomal RNA",
                            "id": "#main/bacterial_noncoding_23S/product_name"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/bacterial_noncoding_23S/seqids"
                        }
                    ],
                    "out": [
                        "#main/bacterial_noncoding_23S/annotations"
                    ],
                    "id": "#main/bacterial_noncoding_23S"
                },
                {
                    "run": "#wf_gcmsearch.cwl",
                    "in": [
                        {
                            "source": "#main/asn_cache",
                            "id": "#main/bacterial_noncoding_5S/asn_cache"
                        },
                        {
                            "source": "#main/model_path",
                            "id": "#main/bacterial_noncoding_5S/model_path"
                        },
                        {
                            "source": "#main/rfam_amendments",
                            "id": "#main/bacterial_noncoding_5S/rfam_amendments"
                        },
                        {
                            "source": "#main/rfam_stockholm",
                            "id": "#main/bacterial_noncoding_5S/rfam_stockholm"
                        },
                        {
                            "source": "#main/seqids",
                            "id": "#main/bacterial_noncoding_5S/seqids"
                        },
                        {
                            "source": "#main/taxon_db",
                            "id": "#main/bacterial_noncoding_5S/taxon_db"
                        }
                    ],
                    "out": [
                        "#main/bacterial_noncoding_5S/annots"
                    ],
                    "id": "#main/bacterial_noncoding_5S"
                }
            ],
            "id": "#main"
        },
        {
            "label": "BLAST against rRNA db",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_blastn.cwl/asn_cache"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/blastdb"
                },
                {
                    "type": "Directory",
                    "id": "#wf_blastn.cwl/blastdb_dir"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/outname"
                },
                {
                    "type": "string",
                    "id": "#wf_blastn.cwl/product_name"
                },
                {
                    "type": "File",
                    "id": "#wf_blastn.cwl/seqids"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/annotations",
                    "id": "#wf_blastn.cwl/annotations"
                }
            ],
            "steps": [
                {
                    "run": "#blastn_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/asn_cache",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/jobs",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode/input_jobs"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode/outdir"
                    ],
                    "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode"
                },
                {
                    "run": "#gpx_make_outputs.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_blastn_wnode/outdir",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_make_outputs/input_path"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_make_outputs/blast_align"
                    ],
                    "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_make_outputs"
                },
                {
                    "run": "#gpx_qsubmit_blastn.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/asn_cache",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/seqids",
                            "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/seqids"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit/jobs"
                    ],
                    "id": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_qsubmit"
                },
                {
                    "run": "#ribosomal_align2annot.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/aligns",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/alignments"
                        },
                        {
                            "source": "#wf_blastn.cwl/outname",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/annotation"
                        },
                        {
                            "source": "#wf_blastn.cwl/asn_cache",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/blastdb_dir"
                        },
                        {
                            "source": "#wf_blastn.cwl/product_name",
                            "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/product_name"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/Generate_nS_rRNA_Annotation/annotations"
                    ],
                    "id": "#wf_blastn.cwl/Generate_nS_rRNA_Annotation"
                },
                {
                    "run": "#align_merge.cwl",
                    "in": [
                        {
                            "source": "#wf_blastn.cwl/BLAST_against_nS_rRNA_db_gpx_make_outputs/blast_align",
                            "id": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/alignments"
                        },
                        {
                            "source": "#wf_blastn.cwl/asn_cache",
                            "id": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/asn_cache"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb",
                            "id": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/blastdb"
                        },
                        {
                            "source": "#wf_blastn.cwl/blastdb_dir",
                            "id": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/blastdb_dir"
                        }
                    ],
                    "out": [
                        "#wf_blastn.cwl/Merge_nS_rRNA_Alignments/aligns"
                    ],
                    "id": "#wf_blastn.cwl/Merge_nS_rRNA_Alignments"
                }
            ],
            "id": "#wf_blastn.cwl"
        },
        {
            "label": "Run genomic CMsearch (5S rRNA)",
            "class": "Workflow",
            "inputs": [
                {
                    "type": "Directory",
                    "id": "#wf_gcmsearch.cwl/asn_cache"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/model_path"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/rfam_amendments"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/rfam_stockholm"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/seqids"
                },
                {
                    "type": "File",
                    "id": "#wf_gcmsearch.cwl/taxon_db"
                }
            ],
            "outputs": [
                {
                    "type": "File",
                    "outputSource": "#wf_gcmsearch.cwl/Post_process_CMsearch_annotations_5S_rRNA/annots",
                    "id": "#wf_gcmsearch.cwl/annots"
                }
            ],
            "steps": [
                {
                    "run": "#annot_merge.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/asn_cache",
                            "id": "#wf_gcmsearch.cwl/Post_process_CMsearch_annotations_5S_rRNA/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_dump/annots",
                            "id": "#wf_gcmsearch.cwl/Post_process_CMsearch_annotations_5S_rRNA/input"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/Post_process_CMsearch_annotations_5S_rRNA/annots"
                    ],
                    "id": "#wf_gcmsearch.cwl/Post_process_CMsearch_annotations_5S_rRNA"
                },
                {
                    "run": "#gpx_qdump.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/outdir",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_dump/input_path"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_dump/annots"
                    ],
                    "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_dump"
                },
                {
                    "run": "#gpx_qsubmit_gcmsearch.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/asn_cache",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_submit/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/seqids",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_submit/seqids"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_submit/jobs"
                    ],
                    "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_submit"
                },
                {
                    "run": "#cmsearch_wnode.cwl",
                    "in": [
                        {
                            "source": "#wf_gcmsearch.cwl/asn_cache",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/asn_cache"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_submit/jobs",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/input_jobs"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/model_path",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/model_path"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/rfam_amendments",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/rfam_amendments"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/rfam_stockholm",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/rfam_stockholm"
                        },
                        {
                            "source": "#wf_gcmsearch.cwl/taxon_db",
                            "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/taxon_db"
                        }
                    ],
                    "out": [
                        "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode/outdir"
                    ],
                    "id": "#wf_gcmsearch.cwl/Run_genomic_CMsearch_5S_rRNA_wnode"
                }
            ],
            "id": "#wf_gcmsearch.cwl"
        }
    ],
    "cwlVersion": "v1.0"
}
